@@ -41,7 +41,7 @@ class Directories:
 @dataclass
 class Scheduling:
     global_max_jobs: int
-    global_stagger_m: int
+    global_stagger_m: List[int]
     polling_time_s: int
     tmpdir_max_jobs: int
     tmpdir_stagger_phase_major: int
